.. _API Reference:

=============
API Reference
=============

The reference guide contains a detailed description of the functions,
modules, and objects included in the library. The reference describes how the
methods work and which parameters can be used. It assumes that you have an
understanding of the key concepts.

.. toctree::
    :maxdepth: 6
    
    /api/api_deepdict
    /api/api_utils